@@ -17,3 +17,7 @@ class DependencyMissing(Exception):
     """Missing a dependency to use an optional feature."""
 
     ...
+
+
+class SourceNotFound(Exception):
+    """Could not find the requested source instance."""
