@@ -31,12 +31,12 @@ class Metric:
         self.monitor_id: str = ""
         self.ref = ref or str(uuid4())
         self.value = value
-        self.created_at = datetime.datetime.now(tz=datetime.timezone.utc)
+        self.created_at = datetime.datetime.utcnow()
         self.updated_at = self.created_at
 
     def pre_save(self, monitor_id: str) -> JDict:
         """Readythe Metric for storage."""
-        self.updated_at = datetime.datetime.now(tz=datetime.timezone.utc)
+        self.updated_at = datetime.datetime.utcnow()
         self.monitor_id = monitor_id
         return self.to_dict()
 
@@ -94,7 +94,7 @@ class Metric:
         if self.created_at.date() == datetime.date.today():
             return f"{formatted_date} - NEW TODAY!"
         else:
-            return f"{formatted_date} - {(self.created_at - datetime.datetime.now(tz=datetime.timezone.utc)).days} days ago"
+            return f"{formatted_date} - {(self.created_at - datetime.datetime.utcnow()).days} days ago"
 
 
 class Sinner(Metric):
