@@ -4,11 +4,11 @@ Requires the requests library to be installed.
 
 from sinai.adaptors.api import ApiConnection
 from sinai.exceptions import SourceError
-from sinai.sources import Source
+from sinai.stores.base import Store
 from sinai.types import JDict, MonitorInstance, PostResponse, RequestResponse
 
 
-class ApiStore(Source, ApiConnection):
+class ApiStore(Store, ApiConnection):
     """Send data to an API endpoint."""
 
     def __init__(self, monitor: MonitorInstance):
